django-admirarchy documentation
===============================
https://github.com/idlesign/django-admirarchy



Description
-----------

*Django Admin addon to navigate through hierarchies.*


Have you ever wanted Django Admin to be able to navigate through hierarchies?

Admirarchy does it in an old-school way, just like Norton Commander and Co - one level at a time.



Requirements
------------

1. Python 2.7+, 3.3+
2. Django 1.5+
3. Django Admin contrib



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    advanced



Get involved into django-admirarchy
-----------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do that at https://github.com/idlesign/django-admirarchy/issues

**Write code.** If you are eager to participate in application development, fork it at https://github.com/idlesign/django-admirarchy, write your code, whether it should be a bugfix or a feature implementation, and make a pull request right from the forked project page.

**Translate.** If want to translate the application into your native language use Transifex: https://www.transifex.com/projects/p/django-admirarchy/.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest for the others — publish them.


Also
----

If the application is not what you want for hierarchies navigation, you might be interested in considering the other choices — https://www.djangopackages.com/grids/g/tree-traversal/
